@@ -7,7 +7,7 @@ import (
 	"sort"
 )
 
-func (env *env) execute(bc *Code, v interface{}, vars ...interface{}) Iter {
+func (env *env) execute(bc *Code, v any, vars ...any) Iter {
 	env.codes = bc.codes
 	env.codeinfos = bc.codeinfos
 	env.push(v)
@@ -18,7 +18,7 @@ func (env *env) execute(bc *Code, v interface{}, vars ...interface{}) Iter {
 	return env
 }
 
-func (env *env) Next() (interface{}, bool) {
+func (env *env) Next() (any, bool) {
 	var err error
 	pc, callpc, index := env.pc, len(env.codes)-1, -1
 	backtrack, hasCtx := env.backtrack, env.ctx != context.Background()
@@ -58,7 +58,7 @@ loop:
 				break loop
 			}
 			n := code.v.(int)
-			m := make(map[string]interface{}, n)
+			m := make(map[string]any, n)
 			for i := 0; i < n; i++ {
 				v, k := env.pop(), env.pop()
 				s, ok := k.(string)
@@ -71,7 +71,7 @@ loop:
 			env.push(m)
 		case opappend:
 			i := env.index(code.v.([2]int))
-			env.values[i] = append(env.values[i].([]interface{}), env.pop())
+			env.values[i] = append(env.values[i].([]any), env.pop())
 		case opfork:
 			if backtrack {
 				if err != nil {
@@ -157,7 +157,7 @@ loop:
 			}
 			p, v := code.v, env.pop()
 			if code.op == opindexarray && v != nil {
-				if _, ok := v.([]interface{}); !ok {
+				if _, ok := v.([]any); !ok {
 					err = &expectedArrayError{v}
 					break loop
 				}
@@ -183,13 +183,13 @@ loop:
 			case int:
 				pc, callpc, index = v, pc, env.scopes.index
 				goto loop
-			case [3]interface{}:
+			case [3]any:
 				argcnt := v[1].(int)
 				x, args := env.pop(), env.args[:argcnt]
 				for i := 0; i < argcnt; i++ {
 					args[i] = env.pop()
 				}
-				w := v[0].(func(interface{}, []interface{}) interface{})(x, args)
+				w := v[0].(func(any, []any) any)(x, args)
 				if e, ok := w.(error); ok {
 					if er, ok := e.(*exitCodeError); !ok || er.value != nil || er.halt {
 						err = e
@@ -211,7 +211,7 @@ loop:
 							break loop
 						}
 						env.paths.push(pathValue{
-							path:  map[string]interface{}{"start": args[2], "end": args[1]},
+							path:  map[string]any{"start": args[2], "end": args[1]},
 							value: w,
 						})
 					case "getpath":
@@ -219,7 +219,7 @@ loop:
 							err = &invalidPathError{x}
 							break loop
 						}
-						for _, p := range args[0].([]interface{}) {
+						for _, p := range args[0].([]any) {
 							env.paths.push(pathValue{path: p, value: w})
 						}
 					}
@@ -257,7 +257,7 @@ loop:
 			env.scopes.push(scope{xs[0], env.offset, callpc, saveindex, outerindex})
 			env.offset += xs[1]
 			if env.offset > len(env.values) {
-				vs := make([]interface{}, env.offset*2)
+				vs := make([]any, env.offset*2)
 				copy(vs, env.values)
 				env.values = vs
 			}
@@ -278,7 +278,7 @@ loop:
 			switch v := env.pop().(type) {
 			case []pathValue:
 				xs = v
-			case []interface{}:
+			case []any:
 				if !env.paths.empty() && env.expdepth == 0 && !env.pathIntact(v) {
 					err = &invalidPathIterError{v}
 					break loop
@@ -290,7 +290,7 @@ loop:
 				for i, v := range v {
 					xs[i] = pathValue{path: i, value: v}
 				}
-			case map[string]interface{}:
+			case map[string]any:
 				if !env.paths.empty() && env.expdepth == 0 && !env.pathIntact(v) {
 					err = &invalidPathIterError{v}
 					break loop
@@ -367,11 +367,11 @@ loop:
 	return nil, false
 }
 
-func (env *env) push(v interface{}) {
+func (env *env) push(v any) {
 	env.stack.push(v)
 }
 
-func (env *env) pop() interface{} {
+func (env *env) pop() any {
 	return env.stack.pop()
 }
 
@@ -415,15 +415,15 @@ func (env *env) index(v [2]int) int {
 }
 
 type pathValue struct {
-	path, value interface{}
+	path, value any
 }
 
-func (env *env) pathIntact(v interface{}) bool {
+func (env *env) pathIntact(v any) bool {
 	w := env.paths.top().(pathValue).value
 	switch v := v.(type) {
-	case []interface{}, map[string]interface{}:
+	case []any, map[string]any:
 		switch w.(type) {
-		case []interface{}, map[string]interface{}:
+		case []any, map[string]any:
 			v, w := reflect.ValueOf(v), reflect.ValueOf(w)
 			return v.Pointer() == w.Pointer() && v.Len() == w.Len()
 		}
@@ -435,8 +435,8 @@ func (env *env) pathIntact(v interface{}) bool {
 	return v == w
 }
 
-func (env *env) poppaths() []interface{} {
-	var xs []interface{}
+func (env *env) poppaths() []any {
+	var xs []any
 	for {
 		p := env.paths.pop().(pathValue)
 		if p.path == nil {
